"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseClickHouseQueryWithoutCursor = exports.parseClickHouseQuery = exports.parsePostgreSqlQueryWithoutCursor = exports.parsePostgreSqlQuery = exports.parseMySqlQueryWithoutCursor = exports.parseMySqlQuery = exports.cursorSymbol = void 0;
const clickhouseAutocompleteParser_1 = require("./parsers/clickhouse/clickhouseAutocompleteParser");
const mysqlAutocompleteParser_1 = require("./parsers/mysql/mysqlAutocompleteParser");
const postgresqlAutocompleteParser_1 = require("./parsers/postgresql/postgresqlAutocompleteParser");
exports.cursorSymbol = '†';
class Parser {
}
function parseMySqlQuery(queryBeforeCursor, queryAfterCursor) {
    const parser = mysqlAutocompleteParser_1.mysqlAutocompleteParser;
    return parser.parseSql(queryBeforeCursor, queryAfterCursor);
}
exports.parseMySqlQuery = parseMySqlQuery;
function parseMySqlQueryWithoutCursor(query) {
    return parseMySqlQuery(getFinishedQuery(query), '');
}
exports.parseMySqlQueryWithoutCursor = parseMySqlQueryWithoutCursor;
function parsePostgreSqlQuery(queryBeforeCursor, queryAfterCursor) {
    const parser = postgresqlAutocompleteParser_1.postgresqlAutocompleteParser;
    return parser.parseSql(queryBeforeCursor, queryAfterCursor);
}
exports.parsePostgreSqlQuery = parsePostgreSqlQuery;
function parsePostgreSqlQueryWithoutCursor(query) {
    return parsePostgreSqlQuery(getFinishedQuery(query), '');
}
exports.parsePostgreSqlQueryWithoutCursor = parsePostgreSqlQueryWithoutCursor;
function parseClickHouseQuery(queryBeforeCursor, queryAfterCursor) {
    const parser = clickhouseAutocompleteParser_1.clickhouseAutocompleteParser;
    return parser.parseSql(queryBeforeCursor, queryAfterCursor);
}
exports.parseClickHouseQuery = parseClickHouseQuery;
function parseClickHouseQueryWithoutCursor(query) {
    return parseClickHouseQuery(getFinishedQuery(query), '');
}
exports.parseClickHouseQueryWithoutCursor = parseClickHouseQueryWithoutCursor;
function getFinishedQuery(query) {
    // If our finished query is "SELECT * FROM|" and we try to parse it, parser thinks that we still haven't finished writing it and doesn't show some errors.
    // In order to truly complete a finished query, we need to add space to it like so "SELECT * FROM |".
    return query + ' ';
}
